@@ -26,6 +26,8 @@ Read the user manual for a description of the interface to this scoring engine
 
 from util import m18n, m18nc, m18nE, english
 
+from tile import Tile
+
 CONCEALED, EXPOSED, ALLSTATES = 1, 2, 3
 EMPTY, SINGLE, PAIR, CHOW, PUNG, KONG, CLAIMEDKONG, ALLMELDS, REST = \
         0, 1, 2, 4, 8, 16, 32, 63, 128
@@ -65,10 +67,15 @@ def stateName(state):
     return '|'.join(parts)
 
 def elementKey(element):
-    """to be used in sort() and sorted() as key=. Sort by tile type, value, case"""
-    tileOrder = 'xdwsbcfy'
-    aPos = tileOrder.index(element[0].lower()) + ord('0')
-    return ''.join([chr(aPos), element[1], element])
+    """to be used in sort() and sorted() as key=. Sort by tile type, value, case.
+    element can also be a meld from the summary."""
+    group = element[0].lower()
+    aPos = chr('xdwsbcfy'.index(group) + ord('0'))
+    bPos = element[1].lower()
+    if group in 'wfy' and bPos in 'eswn':
+        bPos = chr('eswn'.index(bPos) + ord('0'))
+    # add element: upper/lowercase should have a defined order too
+    return aPos + bPos + element
 
 def tileKey(tile):
     """for tile sorting"""
@@ -149,7 +156,7 @@ class Score(object):
             raise Exception('this score must not hold more than one unit: %s' % self.__str__())
 
     @apply
-    def unit(): # pylint: disable-msg=E0202
+    def unit(): # pylint: disable=E0202
         """for use in ruleset tree view. returns an index into Score.units."""
         def fget(self):
             self.assertSingleUnit()
@@ -312,13 +319,16 @@ class Meld(object):
     raise exceptions if the meld is empty. But we do not care,
     those methods are not supposed to be called on empty melds.
     Meld firstly holds the tile elements like 's1','s2','s3' but its
-    attribute tiles can also hold references to the visual tile objects"""
+    attribute tiles can also hold references to the visual tile objects.
+    The name of the tile element in the meld does not have to be
+    identical with the name of the corresponding real tile while tiles
+    are added or removed. See end of SelectorBoard.meldVariants()."""
 
     tileNames = {'x':m18nc('kajongg','hidden'), 's': m18nc('kajongg','stone') ,
         'b': m18nc('kajongg','bamboo'), 'c':m18nc('kajongg','character'),
         'w':m18nc('kajongg','wind'), 'd':m18nc('kajongg','dragon'),
         'f':m18nc('kajongg','flower'), 'y':m18nc('kajongg','season')}
-    valueNames = {'Y':m18nc('kajongg','tile'), 'b':m18nc('kajongg','white'),
+    valueNames = {'y':m18nc('kajongg','tile'), 'b':m18nc('kajongg','white'),
         'r':m18nc('kajongg','red'), 'g':m18nc('kajongg','green'),
         'e':m18nc('kajongg','east'), 's':m18nc('kajongg','south'), 'w':m18nc('kajongg','west'),
         'n':m18nc('kajongg','north'),
@@ -336,15 +346,15 @@ class Meld(object):
         self.__valid = False
         self.score = Score()
         self.meldType = None
-        self.slot = None
-        # do not use isinstance(x,Tile) because we do not want to import Tile - this code
-        # should work on the server, so use as few Qt/KDE references as possible
         if isinstance(newContent, list) and newContent and hasattr(newContent[0], 'focusable'):
             self.joined = ''.join(x.element for x in newContent)
             self.tiles = newContent
         elif isinstance(newContent, Meld):
             self.joined = newContent.joined
             self.tiles = newContent.tiles
+        elif isinstance(newContent, Tile):
+            self.joined = newContent.element
+            self.tiles = [newContent]
         else:
             self.joined = newContent
             self.tiles = []
@@ -388,10 +398,10 @@ class Meld(object):
         return False
 
     @apply
-    def state(): # pylint: disable-msg=E0202
+    def state(): # pylint: disable=E0202
         """meld state"""
         def fget(self):
-            # pylint: disable-msg=W0212
+            # pylint: disable=W0212
             firsts = self.__pairs.startChars()
             if ''.join(firsts).islower():
                 return EXPOSED
@@ -402,7 +412,7 @@ class Meld(object):
             else:
                 return CONCEALED
         def fset(self, state):
-            # pylint: disable-msg=W0212
+            # pylint: disable=W0212
             if state == EXPOSED:
                 self.__pairs.toLower()
                 if self.meldType == CLAIMEDKONG:
@@ -451,22 +461,22 @@ class Meld(object):
         """return one of d w s b c f y"""
         return self.__pairs[0][0].lower()
 
-    def isDragon(self):
-        """is it a meld of dragons?"""
-        return self.__pairs[0][0] in 'dD'
-
-    def isWind(self):
-        """is it a meld of winds?"""
-        return self.__pairs[0][0] in 'wW'
-
-    def isColor(self):
-        """is it a meld of colors?"""
-        return self.__pairs[0][0] in 'sSbBcC'
+    def isSingle(self):
+        """is this meld a pair?"""
+        return self.meldType == SINGLE
 
     def isPair(self):
         """is this meld a pair?"""
         return self.meldType == PAIR
 
+    def isChow(self):
+        """is this meld a pair?"""
+        return self.meldType == CHOW
+
+    def isPung(self):
+        """is this meld a pair?"""
+        return self.meldType == PUNG
+
     def isKong(self):
         """is it a kong?"""
         return self.meldType in (KONG, CLAIMEDKONG)
@@ -487,18 +497,18 @@ class Meld(object):
     def pairs():
         """make them readonly"""
         def fget(self):
-            # pylint: disable-msg=W0212
+            # pylint: disable=W0212
             return self.__pairs
         return property(**locals())
 
     @apply
-    def joined(): # pylint: disable-msg=E0202
+    def joined(): # pylint: disable=E0202
         """content"""
         def fget(self):
-            # pylint: disable-msg=W0212
+            # pylint: disable=W0212
             return ''.join(self.__pairs)
         def fset(self, newContent):
-            # pylint: disable-msg=W0212
+            # pylint: disable=W0212
             self.__pairs = Pairs(newContent)
             self.__valid = True
             self.meldType = self._getMeldType()
@@ -518,4 +528,3 @@ class Meld(object):
                 self.__pairs.toLower(0)
                 self.__pairs.toUpper(1, 3)
                 self.__pairs.toLower(3)
-
