@@ -28,9 +28,9 @@ from PyQt4.QtGui import QDialog, QStringListModel, QListView, QSplitter, QValida
 from PyQt4.QtGui import QIcon, QPixmap, QPainter, QDialogButtonBox
 from PyQt4.QtGui import QSizePolicy, QComboBox, QCheckBox, QScrollBar
 from PyQt4.QtSql import QSqlQueryModel
-from PyKDE4.kdeui import KDialogButtonBox
+from PyKDE4.kdeui import KDialogButtonBox, KApplication
 
-from genericdelegates import GenericDelegate, IntegerColumnDelegate
+from genericdelegates import IntegerColumnDelegate
 
 from rulesetselector import RuleTreeView
 from board import WindLabel, WINDPIXMAPS, ROUNDWINDCOLOR
@@ -121,12 +121,10 @@ class ScoreTable(QWidget):
             view.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
             view.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
             view.setModel(model)
-            delegate = GenericDelegate(self)
-            delegate.insertColumnDelegate(self.__tableFields.index('payments'),
-                IntegerColumnDelegate())
-            delegate.insertColumnDelegate(self.__tableFields.index('balance'),
-                IntegerColumnDelegate())
-            view.setItemDelegate(delegate)
+            view.setItemDelegateForColumn(self.__tableFields.index('payments'),
+                IntegerColumnDelegate(view))
+            view.setItemDelegateForColumn(self.__tableFields.index('balance'),
+                IntegerColumnDelegate(view))
             view.setFocusPolicy(Qt.NoFocus)
             if idx != 3:
                 view.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
@@ -147,6 +145,9 @@ class ScoreTable(QWidget):
                 self.updateHscroll)
         self.ruleTree = RuleTreeView(m18nc('kajongg','Used Rules'))
         self.splitter.addWidget(self.ruleTree)
+        # this shows just one line for the ruleTree - so we just see the
+        # name of the ruleset:
+        self.splitter.setSizes(list([1000, 1]))
 
     def updateDetailScroll(self, value):
         """synchronise all four views"""
@@ -184,12 +185,25 @@ class ScoreTable(QWidget):
         model.setHeaderData(self.__tableFields.index('balance'),
                 Qt.Horizontal, QVariant(u"\u2211"))
 
+    def sizeHint(self):
+        """give the scoring table window a sensible default size"""
+        result = QWidget.sizeHint(self)
+        result.setWidth(result.height() * 3 / 2)
+        # the default is too small. Use at least 2/5 of screen height and 1/4 of screen width:
+        available = KApplication.kApplication().desktop().availableGeometry()
+        height = max(result.height(), available.height() * 2 / 5)
+        width = max(result.width(), available.width() / 4)
+        result.setHeight(height)
+        result.setWidth(width)
+        return result
+
     def refresh(self, game):
         """load this game and this player. Keep parameter list identical with
         ExplainView"""
         self.game = game
         if not self.game:
             return
+        # TODO: for 4.6.1, say "for this game" for scoring games
         if self.game.finished():
             title = m18n('Final scores for game <numid>%1</numid>', str(self.game.seed))
         else:
@@ -262,13 +276,6 @@ class PenaltyBox(QSpinBox):
                 result = QValidator.Intermediate
         return (result, newPos)
 
-    def stepBy(self, steps):
-        """this does not go thru the validator..."""
-        newExpected = self.value() + steps * self.singleStep()
-        remainder = newExpected % self.parties
-        self.setValue(newExpected - remainder)
-        self.selectAll()
-
 class RuleBox(QCheckBox):
     """additional attribute: ruleId"""
     def __init__(self, rule):
@@ -413,8 +420,8 @@ class PenaltyDialog(QDialog):
 
 class ScoringDialog(QWidget):
     """a dialog for entering the scores"""
-    # pylint: disable-msg=R0902
-    # pylint: we need more than 10 instance attributes
+    # pylint: disable=R0902
+    # pylint we need more than 10 instance attributes
 
     def __init__(self, game):
         QWidget.__init__(self, None)
@@ -436,6 +443,7 @@ class ScoringDialog(QWidget):
         pGrid.addWidget(QLabel(m18nc('kajongg', 'Score')), 0, 2)
         pGrid.addWidget(QLabel(m18n("Winner")), 0, 3)
         self.detailTabs = QTabWidget()
+        self.detailTabs.setDocumentMode(True)
         pGrid.addWidget(self.detailTabs, 0, 4, 8, 1)
         for idx in range(4):
             self.setupUiForPlayer(pGrid, idx)
@@ -610,7 +618,10 @@ class ScoringDialog(QWidget):
                         for pBox in player.manualRuleBoxes:
                             if pBox.rule.name == ruleBox.rule.name:
                                 pBox.setChecked(False)
-        newState = bool(self.game and self.game.winner and self.game.winner.handBoard.allTiles())
+        try:
+            newState = bool(self.game.winner.handBoard.tiles)
+        except AttributeError:
+            newState = False
         self.lblLastTile.setEnabled(newState)
         self.cbLastTile.setEnabled(newState)
         self.lblLastMeld.setEnabled(newState)
@@ -623,7 +634,6 @@ class ScoringDialog(QWidget):
         """prepare for next hand"""
         if self.game:
             for idx, player in enumerate(self.game.players):
-                player.handBoard.clear()
                 self.spValues[idx].clear()
                 self.spValues[idx].setValue(0)
                 self.wonBoxes[idx].setChecked(False)
@@ -639,7 +649,7 @@ class ScoringDialog(QWidget):
         else:
             for idx, player in enumerate(self.game.players):
                 self.windLabels[idx].setPixmap(WINDPIXMAPS[(player.wind,
-                            player.wind == WINDS[self.game.roundsFinished])])
+                            player.wind == WINDS[self.game.roundsFinished % 4])])
             self.computeScores()
             self.spValues[0].setFocus()
             self.spValues[0].selectAll()
@@ -654,7 +664,7 @@ class ScoringDialog(QWidget):
         for idx, player in enumerate(self.game.players):
             self.spValues[idx].blockSignals(True) # we do not want that change to call computeScores again
             self.wonBoxes[idx].blockSignals(True) # we do not want that change to call computeScores again
-            if player.handBoard and player.handBoard.allTiles():
+            if player.handBoard and player.handBoard.tiles:
                 self.spValues[idx].setEnabled(False)
                 for loop in range(10):
                     prevTotal = player.handTotal
@@ -688,7 +698,7 @@ class ScoringDialog(QWidget):
         lastTiles = set()
         winnerTiles = []
         if self.game.winner and self.game.winner.handBoard:
-            winnerTiles = self.game.winner.handBoard.allTiles()
+            winnerTiles = self.game.winner.handBoard.tiles
             pairs = []
             for meld in self.game.winner.computeHandContent().melds:
                 if len(meld) < 4:
@@ -709,7 +719,7 @@ class ScoringDialog(QWidget):
         self.cbLastTile.clear()
         if not winnerTiles:
             return
-        pmSize = winnerTiles[0].tileset.faceSize
+        pmSize = winnerTiles[0].board.tileset.faceSize
         pmSize = QSize(pmSize.width() * 0.5, pmSize.height() * 0.5)
         self.cbLastTile.setIconSize(pmSize)
         QPixmapCache.clear()
@@ -718,7 +728,8 @@ class ScoringDialog(QWidget):
         for tile in winnerTiles:
             if tile.element in lastTiles and tile.element not in shownTiles:
                 shownTiles.add(tile.element)
-                self.cbLastTile.addItem(QIcon(tile.pixmap(pmSize)), '', QVariant(tile.element))
+                self.cbLastTile.addItem(QIcon(tile.graphics.pixmapFromSvg(pmSize, withBorders=False)),
+                        '', QVariant(tile.element))
                 if indexedTile == tile.element:
                     restoredIdx = self.cbLastTile.count() - 1
         if not restoredIdx and indexedTile:
@@ -763,7 +774,7 @@ class ScoringDialog(QWidget):
             for element in meld.pairs:
                 painter.drawPixmap(0, 0,
                     winner.handBoard.tilesByElement(element) \
-                    [0].pixmap(faceWidth, faceHeight))
+                    [0].graphics.pixmapFromSvg(QSize(faceWidth, faceHeight), withBorders=False))
                 painter.translate(QPointF(faceWidth, 0.0))
             self.cbLastMeld.addItem(QIcon(pixMap), '', QVariant(meld.joined))
             if indexedMeld == meld.joined:
