@@ -1,5 +1,6 @@
 /*
     Copyright (C) 2002-2005, Jason Katz-Brown <jasonkb@mit.edu>
+    Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,31 +18,18 @@
 */
 
 #include "newgame.h"
-
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
-#include <kscoredialog.h>
-#include <kstandarddirs.h>
-#include <kseparator.h>
-#include <klineedit.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kurllabel.h>
-#include <ktoolinvocation.h>
-
-#include <QCheckBox>
-#include <QLabel>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <k3listbox.h>
-#include <QScrollArea>
-#include <QPixmapCache>
-
 #include "game.h"
 
+#include <QBoxLayout>
+#include <QLabel>
+#include <QListWidget>
+#include <KFileDialog>
+#include <KMessageBox>
+#include <KPushButton>
+#include <KScoreDialog>
+#include <KSeparator>
+#include <KStandardDirs>
+
 NewGameDialog::NewGameDialog(bool enableCourses)
 	: KPageDialog()
 {
@@ -142,12 +130,12 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		names.append(QString());
 		nameList.append(newName);
 
-		courseList = new K3ListBox(coursePage);
+		courseList = new QListWidget(coursePage);
 		hlayout->addWidget(courseList);
-		courseList->insertStringList(nameList);
-		courseList->setCurrentItem(curItem);
-		connect(courseList, SIGNAL(highlighted(int)), this, SLOT(courseSelected(int)));
-		connect(courseList, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
+		courseList->addItems(nameList);
+		courseList->setCurrentRow(curItem);
+		connect(courseList, SIGNAL(currentRowChanged(int)), this, SLOT(courseSelected(int)));
+		connect(courseList, SIGNAL(itemSelectionChanged()), this, SLOT(selectionChanged()));
 
 		QVBoxLayout *detailLayout = new QVBoxLayout;
                 detailLayout->setSpacing( spacingHint() );
@@ -264,25 +252,25 @@ void NewGameDialog::showHighscores()
 
 void NewGameDialog::removeCourse()
 {
-	int curItem = courseList->currentItem();
-	if (curItem < 0)
+	QListWidgetItem* curItem = courseList->currentItem();
+	if (!curItem)
 		return;
 
-	QString file = names.at(curItem);
+	QString file = curItem->text();
 	if (!externCourses.contains(file))
 		return;
 
 	names.removeAll(file);
 	externCourses.removeAll(file);
-	courseList->removeItem(curItem);
+	delete courseList->takeItem(courseList->currentRow());
 
 	selectionChanged();
 }
 
 void NewGameDialog::selectionChanged()
 {
-	const int curItem = courseList->currentItem();
-	remove->setEnabled(!(curItem < 0 || !externCourses.contains(names.at(curItem))));
+	QListWidgetItem* curItem = courseList->currentItem();
+	remove->setEnabled(curItem && externCourses.contains(curItem->text()));
 }
 
 void NewGameDialog::addCourse()
@@ -306,7 +294,7 @@ void NewGameDialog::addCourse()
 		names.prepend(*fileIt);
 		externCourses.prepend(*fileIt);
 
-		courseList->insertItem(curinfo.name, 0);
+		courseList->insertItem(0, new QListWidgetItem(curinfo.name));
 	}
 
 	if (hasDuplicates)
