@@ -53,7 +53,7 @@ protected:
     virtual QString getGameState();
     virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
     virtual bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const;
-    virtual void restart();
+    virtual void restart( const QList<KCard*> & cards );
 
 protected slots:
     virtual bool newCards();
