@@ -62,67 +62,67 @@ KTron::KTron(QWidget *parent) : KXmlGuiWindow(parent, KDE_DEFAULT_WINDOWFLAGS) {
 	setCentralWidget(m_tron);
 
 	// create statusbar
-	statusBar()->insertItem("abcdefghijklmnopqrst: 0  ",ID_STATUS_BASE + 1);
-	statusBar()->insertItem("abcdefghijklmnopqrst: 0  ",ID_STATUS_BASE + 2);
+	statusBar()->insertItem(QLatin1String( "abcdefghijklmnopqrst: 0  " ),ID_STATUS_BASE + 1);
+	statusBar()->insertItem(QLatin1String( "abcdefghijklmnopqrst: 0  " ),ID_STATUS_BASE + 2);
 
 	// We match up keyboard events ourselves in Tron::keyPressEvent()
 	// We must disable the actions, otherwise we don't get the keyPressEvent's
 
-	m_player0Up = actionCollection()->addAction("Pl1Up");
+	m_player0Up = actionCollection()->addAction( QLatin1String( "Pl1Up" ));
 	m_player0Up->setText(i18n("Right Player / KSnake: Up"));
 	m_player0Up->setShortcut(Qt::Key_Up);
 	connect(m_player0Up, SIGNAL(triggered(bool)), SLOT(triggerKey0Up(bool)));
 	addAction(m_player0Up);
 
-	m_player0Down = actionCollection()->addAction("Pl1Down");
+	m_player0Down = actionCollection()->addAction( QLatin1String( "Pl1Down" ));
 	m_player0Down->setText(i18n("Right Player / KSnake: Down"));
 	m_player0Down->setShortcut(Qt::Key_Down);
 	connect(m_player0Down, SIGNAL(triggered(bool)), SLOT(triggerKey0Down(bool)));
 	addAction(m_player0Down);
 
-	m_player0Right = actionCollection()->addAction("Pl1Right");
+	m_player0Right = actionCollection()->addAction( QLatin1String( "Pl1Right" ));
 	m_player0Right->setText(i18n("Right Player / KSnake: Right"));
 	m_player0Right->setShortcut(Qt::Key_Right);
 	connect(m_player0Right, SIGNAL(triggered(bool)), SLOT(triggerKey0Right(bool)));
 	addAction(m_player0Right);
 
-	m_player0Left = actionCollection()->addAction("Pl1Left");
+	m_player0Left = actionCollection()->addAction( QLatin1String( "Pl1Left" ));
 	m_player0Left->setText(i18n("Right Player / KSnake: Left"));
 	m_player0Left->setShortcut(Qt::Key_Left);
 	connect(m_player0Left, SIGNAL(triggered(bool)), SLOT(triggerKey0Left(bool)));
 	addAction(m_player0Left);
 
-	m_player0Accelerate = actionCollection()->addAction("Pl1Ac");
+	m_player0Accelerate = actionCollection()->addAction( QLatin1String( "Pl1Ac" ));
 	m_player0Accelerate->setText(i18n("Right Player: Accelerator"));
 	m_player0Accelerate->setShortcut(Qt::Key_0);
 	m_player0Accelerate->setEnabled(false); // Alternate handling, because of up/down events
 	addAction(m_player0Accelerate);
 
-	m_player1Up = actionCollection()->addAction("Pl2Up");
+	m_player1Up = actionCollection()->addAction( QLatin1String( "Pl2Up" ));
 	m_player1Up->setText(i18n("Left Player: Up"));
 	m_player1Up->setShortcut(Qt::Key_W);
 	connect(m_player1Up, SIGNAL(triggered(bool)), SLOT(triggerKey1Up(bool)));
 	addAction(m_player1Up);
 
-	m_player1Down = actionCollection()->addAction("Pl2Down");
+	m_player1Down = actionCollection()->addAction( QLatin1String( "Pl2Down" ));
 	m_player1Down->setText(i18n("Left Player: Down"));
 	m_player1Down->setShortcut(Qt::Key_S);
 	connect(m_player1Down, SIGNAL(triggered(bool)), SLOT(triggerKey1Down(bool)));
 	addAction(m_player1Down);
 
-	m_player1Right = actionCollection()->addAction("Pl2Right");;
+	m_player1Right = actionCollection()->addAction( QLatin1String( "Pl2Right" ));;
 	m_player1Right->setText(i18n("Left Player: Right"));
 	m_player1Right->setShortcut(Qt::Key_D);
 	connect(m_player1Right, SIGNAL(triggered(bool)), SLOT(triggerKey1Right(bool)));
 	addAction(m_player1Right);
 
-	m_player1Left = actionCollection()->addAction("Pl2Left");
+	m_player1Left = actionCollection()->addAction( QLatin1String( "Pl2Left" ));
 	m_player1Left->setText(i18n("Left Player: Left"));
 	m_player1Left->setShortcut(Qt::Key_A);
 	connect(m_player1Left, SIGNAL(triggered(bool)), SLOT(triggerKey1Left(bool)));
 	addAction(m_player1Left);
 
-	m_player1Accelerate = actionCollection()->addAction("Pl2Ac");
+	m_player1Accelerate = actionCollection()->addAction( QLatin1String( "Pl2Ac" ));
 	m_player1Accelerate->setText(i18n("Left Player: Accelerator"));
 	m_player1Accelerate->setShortcut(Qt::Key_Q);
 	m_player1Accelerate->setEnabled(false); // Alternate handling, because of up/down events
@@ -180,30 +180,30 @@ void KTron::loadSettings() {
 	if (!m_tron->getPlayer(1)->isComputer()) {
 		Settings::setNamePlayer2(m_tron->getPlayer(1)->getName());
 	}
-	
+
 	updateStatusbar();
 }
 
 void KTron::updateStatusbar() {
 	QString message;
-	
+
 	if (!m_tron->running() && m_tron->hasWinner()) {
 		QString winnerName = m_tron->getPlayer(m_tron->getWinner())->getName();
-		
+
 		message = i18n("%1 has won!", winnerName);
 	}
 	else if (m_tron->paused()) {
 		message = i18n("Game paused");
 	}
 	else {
-		message = QString("");
+		message = QString();
 	}
-	
+
 	statusBar()->showMessage(message);
 
 	if (Settings::gameType() == Settings::EnumGameType::Snake)
 	{
-		QString string = QString("%1: %2").arg(m_tron->getPlayer(0)->getName()).arg(m_tron->getPlayer(0)->getScore());
+		QString string = QString::fromLatin1( "%1: %2").arg(m_tron->getPlayer(0)->getName()).arg(m_tron->getPlayer(0)->getScore());
 		statusBar()->changeItem(string, ID_STATUS_BASE + 1);
 		statusBar()->changeItem(QString(), ID_STATUS_BASE + 2);
 	}
@@ -212,8 +212,8 @@ void KTron::updateStatusbar() {
 		for (int i = 0; i < 2; ++i) {
 			QString name = m_tron->getPlayer(1 - i)->getName();
 			int score = m_tron->getPlayer(1 - i)->getScore();
-			
-			QString string = QString("%1: %2").arg(name).arg(score);
+
+			QString string = QString::fromLatin1( "%1: %2").arg(name).arg(score);
 			statusBar()->changeItem(string, ID_STATUS_BASE + i + 1);
 		}
 	}
@@ -258,9 +258,9 @@ void KTron::paletteChange(const QPalette &){
  * Show Settings dialog.
  */
 void KTron::showSettings(){
-	if (KConfigDialog::showDialog("settings"))
+	if (KConfigDialog::showDialog(QLatin1String( "settings" )))
 		return;
-  
+
 	m_generalConfigDialog = new General();
 
 	if (Settings::gameType() == Settings::EnumGameType::Snake) {
@@ -272,9 +272,9 @@ void KTron::showSettings(){
 		m_generalConfigDialog->namePlayer2Label->setText(i18n("Left Player:"));
 	}
 
-	KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
-	dialog->addPage(m_generalConfigDialog, i18n("General"), "games-config-options");
-	dialog->addPage(new KGameThemeSelector(dialog, Settings::self(), KGameThemeSelector::NewStuffEnableDownload), i18n("Theme"), "games-config-theme");
+	KConfigDialog *dialog = new KConfigDialog(this, QLatin1String( "settings" ), Settings::self());
+	dialog->addPage(m_generalConfigDialog, i18n("General"), QLatin1String( "games-config-options" ));
+	dialog->addPage(new KGameThemeSelector(dialog, Settings::self(), KGameThemeSelector::NewStuffEnableDownload), i18n("Theme"), QLatin1String( "games-config-theme" ));
 	connect(dialog, SIGNAL(settingsChanged(const QString &)), this, SLOT(loadSettings()));
 	connect(dialog, SIGNAL(settingsChanged(const QString &)), m_tron, SLOT(loadSettings()));
 	dialog->show();
