@@ -54,6 +54,7 @@ class KScoreDialog::KScoreDialogPrivate
     public:
         //QList<FieldInfo*> scores;
         QMap<QByteArray, GroupScores> scores; ///<Maps config group name to GroupScores
+        QList<QByteArray> hiddenGroups; /// Groups that should not be shown in the dialog
         QMap<int, QByteArray> configGroupWeights; /// Weights of the groups, defines ordering
         KTabWidget *tabWidget;
         //QWidget *page;
@@ -65,7 +66,7 @@ class KScoreDialog::KScoreDialogPrivate
         QString comment;
         int fields;
         int hiddenFields;
-        QPair<QByteArray, int> newName; //index of the newname to add (groupKey, position)
+        QPair<QByteArray, int> newName; //index of the new name to add (groupKey, position)
         QPair<QByteArray, int> latest; //index of the latest addition (groupKey, position)
         int nrCols;
         bool loaded;
@@ -114,15 +115,15 @@ KScoreDialog::KScoreDialog(int fields, QWidget *parent)
 
     //Set up the default table headers
     d->header[Name] = i18n("Name");
-    d->key[Name] = "Name";
+    d->key[Name] = QLatin1String( "Name" );
     d->header[Date] = i18n("Date");
-    d->key[Date] = "Date";
+    d->key[Date] = QLatin1String( "Date" );
     d->header[Level] = i18n("Level");
-    d->key[Level] = "Level";
+    d->key[Level] = QLatin1String( "Level" );
     d->header[Score] = i18n("Score");
-    d->key[Score] = "Score";
+    d->key[Score] = QLatin1String( "Score" );
     d->header[Time] = i18n("Time");
-    d->key[Time] = "Time";
+    d->key[Time] = QLatin1String( "Time" );
 
     //d->page = new QWidget(this);
 
@@ -161,16 +162,7 @@ void KScoreDialog::setConfigGroup(const QPair<QByteArray, QString>& group)
 
 void KScoreDialog::addLocalizedConfigGroupName(const QPair<QByteArray, QString>& group)
 {
-    bool alreadyPresent = false;
-    foreach(const QByteArray& groupKey, d->translatedGroupNames.keys())
-    {
-        if(groupKey == group.first)
-        {
-            alreadyPresent = true;
-            break;
-        }
-    }
-    if(!alreadyPresent)
+    if (!d->translatedGroupNames.contains(group.first))
     {
         d->translatedGroupNames.insert(group.first, group.second);
         kDebug() << "adding" << group.first << "->" << group.second;
@@ -179,12 +171,18 @@ void KScoreDialog::addLocalizedConfigGroupName(const QPair<QByteArray, QString>&
 
 void KScoreDialog::addLocalizedConfigGroupNames(const QMap<QByteArray, QString>& groups)
 {
-    foreach(const QByteArray& groupKey, groups.keys())
+    QMap<QByteArray, QString>::const_iterator it = groups.begin();
+    for (; it != groups.end(); ++it)
     {
-        addLocalizedConfigGroupName(qMakePair(groupKey, groups.value(groupKey)));
+        addLocalizedConfigGroupName(qMakePair(it.key(), it.value()));
     }
 }
 
+void KScoreDialog::setHiddenConfigGroups(const QList<QByteArray>& hiddenGroups)
+{
+    d->hiddenGroups = hiddenGroups;
+}
+
 void KScoreDialog::setConfigGroupWeights(const QMap<int, QByteArray>& weights)
 {
     d->configGroupWeights = weights;
@@ -192,15 +190,9 @@ void KScoreDialog::setConfigGroupWeights(const QMap<int, QByteArray>& weights)
 
 QString KScoreDialog::KScoreDialogPrivate::findTranslatedGroupName(const QByteArray& name)
 {
-    foreach(const QByteArray& groupKey, translatedGroupNames.keys())
-    {
-        if(name == groupKey) //if this string is the same as the untranslated version in the list
-        {
-            return translatedGroupNames.value(groupKey); //return the translated string for the current locale
-        }
-    }
+    const QString lookupResult = translatedGroupNames.value(name);
     //If it wasn't found then just try i18n( to see if it happens to be in the database
-    return i18n(name); //FIXME?
+    return lookupResult.isEmpty() ? i18n(name) : lookupResult; //FIXME?
 }
 
 void KScoreDialog::setComment(const QString &comment)
@@ -252,6 +244,8 @@ void KScoreDialog::KScoreDialogPrivate::setupDialog()
 
 void KScoreDialog::KScoreDialogPrivate::setupGroup(const QByteArray& groupKey)
 {
+    if (hiddenGroups.contains(groupKey))
+        return;
     QWidget* widget = new QWidget(q);
     tabs[groupKey] = widget;
 
@@ -259,7 +253,7 @@ void KScoreDialog::KScoreDialogPrivate::setupGroup(const QByteArray& groupKey)
     tabWidget->addTab(widget, tabName);
 
     QGridLayout* layout = new QGridLayout(widget);
-    //layout->setObjectName("ScoreTab-"+groupName);
+    //layout->setObjectName( QLatin1String("ScoreTab-" )+groupName);
     layout->setMargin(marginHint()+20);
     layout->setSpacing(spacingHint());
     layout->addItem(new QSpacerItem(0, 15), 4, 0);
@@ -333,8 +327,13 @@ void KScoreDialog::KScoreDialogPrivate::aboutToShow()
         setupDialog();
 
     int tabIndex=0; //Index of the current tab
-    foreach(const QByteArray &groupKey, scores.keys())
+
+    QMap<QByteArray, GroupScores>::const_iterator it = scores.constBegin();
+    for (; it != scores.constEnd(); ++it)
     {
+        const QByteArray &groupKey = it.key();
+        if (hiddenGroups.contains(groupKey))
+            continue;
         kDebug() << latest.first << tabWidget->tabText(tabIndex);
 
         //Only display the comment on the page with the new score (or) this one if there's only one tab
@@ -437,7 +436,7 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
 
     QByteArray tempCurrentGroup = configGroup; //temp to store the user-set group name
 
-    if (!groupKeyList.contains(configGroup)) //If the current group doesn't have any entries, add it to the list to process
+    if (!groupKeyList.contains( configGroup) ) //If the current group doesn't have any entries, add it to the list to process
     {
         kDebug(11002) << "The current high score group " << configGroup << " isn't in the list, adding it";
         groupKeyList << configGroup;
@@ -446,8 +445,8 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
 
     foreach(const QByteArray &groupKey, groupKeyList)
     {
-        highscoreObject->setHighscoreGroup(groupKey);
-        player = highscoreObject->readEntry(0, "LastPlayer");  //FIXME
+        highscoreObject->setHighscoreGroup(QLatin1String( groupKey ));
+        player = highscoreObject->readEntry(0, QLatin1String( "LastPlayer" ));  //FIXME
 
         for (int i = 1; i <= 10; ++i)
         {
@@ -456,16 +455,16 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
             {
                 if (fields & field)
                 {
-                    score[field] = highscoreObject->readEntry(i, key[field], QString("-"));
+                    score[field] = highscoreObject->readEntry(i, key[field], QLatin1String("-"));
                 }
             }
             scores[groupKey].append(score);
         }
     }
-    highscoreObject->setHighscoreGroup(tempCurrentGroup); //reset to the user-set group name
+    highscoreObject->setHighscoreGroup(QLatin1String( tempCurrentGroup )); //reset to the user-set group name
     foreach(const QByteArray &groupKey, scores.keys())
     {
-        if( (scores[groupKey][0].value(Score)=="-") && (scores.size() > 1) && (latest.first != groupKey) )
+        if( (scores[groupKey][0].value(Score)==QLatin1String( "-" )) && (scores.size() > 1) && (latest.first != groupKey) )
         {
             kDebug(11002) << "Removing group " << groupKey << " since it's unused.";
             scores.remove(groupKey);
@@ -476,9 +475,9 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
 
 void KScoreDialog::KScoreDialogPrivate::saveScores()
 {
-    highscoreObject->setHighscoreGroup(configGroup);
+    highscoreObject->setHighscoreGroup(QLatin1String( configGroup ));
 
-    highscoreObject->writeEntry(0,"LastPlayer", player);
+    highscoreObject->writeEntry(0,QLatin1String( "LastPlayer" ), player);
 
     for (int i = 1; i <= 10; ++i)
     {
